#
# spec file for package modem-manager-gui
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           modem-manager-gui
Version:        0.0.19.1
Release:        bp156.3.7
Summary:        Modem Manager GUI
License:        GPL-3.0-or-later
Group:          Hardware/Mobile
Url:            http://linuxonly.ru/cms/page.php?7
Source:         http://download.tuxfamily.org/gsf/source/modem-manager-gui-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE E: env-script-interpreter (Badness: 9)
# /etc/NetworkManager/dispatcher.d/95-mmgui-timestamp-notifier /usr/bin/env python3
# This script uses 'env' as an interpreter. For the rpm runtime dependency
# detection to work, the shebang #!/usr/bin/env python  needs to be patched into
# #!/usr/bin/python  otherwise the package dependency generator merely adds a
# dependency on /usr/bin/env rather than the actual interpreter /usr/bin/python.
# Alternatively, if the file should not be executed, then ensure that it is not
# marked as executable or don't install it in a path that is reserved for executables.
Patch0:         95-mmgui-timestamp-notifier.diff
# PATCH-FIX-OPENSUSE bnc#1154301 Fix memory corruption because of wrong strsep()
# usage. Fix segfault in strftime_l() because of timestamps from future.
Patch1:         fix-crash.patch

BuildRequires:  fdupes
BuildRequires:  gdbm-devel
BuildRequires:  itstool >= 1.2
BuildRequires:  man
BuildRequires:  po4a
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.1
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4.0
Requires:       ModemManager >= 0.5.0.0
Recommends:     %{name}-lang
Suggests:       evolution-data-server >= 3.4.1
Suggests:       libcanberra0 >= 0.28
Suggests:       libnotify-tools >= 0.7.5

%description
This program is simple graphical interface for Modem Manager
daemon dbus interface.
Current features:
- View device information: Operator name, Mode, IMEI, IMSI,
  Signal level.
- Send and receive SMS messages with long massages
  concatenation and store messages in database.
- Send USSD requests and read answers in GSM7 and UCS2 formats
  converted to system UTF8 charset.
- Scan available mobile networks.

%lang_package

%prep
%setup -q
%patch0
%patch1 -p1

%build
%configure
make %{?_smp_mflags}

%install
make install INSTALLPREFIX=%{buildroot}
%find_lang %{name}
%suse_update_desktop_file -r %{name} 'Internet;Monitor;'
%fdupes -s %{buildroot}%{_datadir}/help

%files
%defattr(-,root,root,-)
%license LICENSE
%doc AUTHORS
%doc Changelog
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_mandir}/*
%{_mandir}/*/*
%{_datadir}/metainfo/%{name}.appdata.xml
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/dispatcher.d
%{_sysconfdir}/NetworkManager/dispatcher.d/95-mmgui-timestamp-notifier
# https://bugzilla.novell.com/show_bug.cgi?id=950215
# %%dir %%{_datadir}/polkit-1
# %%dir %%{_datadir}/polkit-1/actions	
%exclude %{_datadir}/polkit-1/actions/ru.linuxonly.modem-manager-gui.policy

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Fri Nov  8 2019 Dmitriy Perlow <dap.darkness@gmail.com>
- Added fix-crash.patch vs. bnc#1154301:
  * Fix memory corruption because of wrong strsep() usage;
  * Fix segfault in strftime_l() because of timestamps from future.
* Thu Jul 26 2018 dap.darkness@gmail.com
- 0.0.19.1:
  * Fixes:
  - building on non-x86 machines;
  - running on system without systemd;
  - couple of small fixes;
  - new Slovak localization by Jozef Gaal;
- 0.0.19:
  * New features:
  - New connection control functionality
    for NetworkManager/Connman;
  - Builtin PIN code input dialog;
  - Active pages selection;
  - Custom command for new SMS;
  - Notifications filtration in GNOME;
  - Traffic graph movement selection;
  - Modules compatibility checks;;
  - Meson build system support;
  - Theme icons support (thanks to Andrei);
  - Monochrome and scalable icons for desktop integration;
  - AppIndicator as replacement for GtkStatusIcon;
  - New translations;
  * Fixes:
  - UI refresh for better look and feel (thanks to Andrei);
  - Registration handler in MM06 fix (thanks to Alexey);
  - Invisible infobar fix;
  - Stalled connection to Akonadi server fix;
  - Akonadi server error handler typo fix (thanks to dcb);
  - Timestamp parser for legacy MM versions fix;
  - Appdata file format and placement fix.
- Added 95-mmgui-timestamp-notifier.diff.
* Wed Jun 22 2016 dap.darkness@gmail.com
- Reverted previous commit. It was wrong.
* Sun Jun 19 2016 dap.darkness@gmail.com
- Let's conflict with evolution-data-server >= 3.16 to finally
  resolve bnc#985560 & bnc#927724.
* Tue Nov 17 2015 dimstar@opensuse.org
- Only run fdupes over /usr/share/help: we must not risk the icon
  in /usr/share/pixmaps to turn in a symlink.
* Tue Oct 13 2015 dap.darkness@gmail.com
- 0.0.18:
  * New features:
  - SystemD integration for easy services activation (DBus
    activation also supported, SystemD is not strictly required);
  - Spell checking for SMS messages (using Gtkspell and Enchant);
  - Extended traffic consumption statistics;
  - SMS list multi-selection mode.
  * Fixes:
  - Evolution Data Server v.0.0.16 API break;
  - Crash on start because of NULL values in SMS structure fields;
  - NDIS devices support;
  - ...and some other.
- Removed modem-manager-gui-0.0.17.1-fix-libebook-api-break.patch.
* Sat Apr 25 2015 dap.darkness@gmail.com
- Added http://download.tuxfamily.org/gsf/patch/…-api-break.patch
  ( modem-manager-gui-0.0.17.1-fix-libebook-api-break.patch )
  because of API break in libebook library from Evolution data
  server version 3.16. Resolves bnc#927724 (openSUSE Factory).
* Tue Sep  2 2014 dap.darkness@gmail.com
- 0.0.17.1:
  * New features:
  - oFono/Connman supprted as well as ModemManager/NetworkManager;
  - KDE addressbook contacts export (not sure if it works fine
    though, additional testing needed);
  - Preferred backends can be selected from GUI;
  - Operations timeouts can be adjusted from GUI;
  - Autocompletion for names of contacts in New SMS dialog and
    names of commands in USSD window added;
  - GNOME-style help added, thanks to Mario Blättermann (it is
    not finished at moment, but much better than nothing);
  - Appdata file added;
  * Fixes:
  - Deadlock on connections handling (at least hope so);
  - Traffic history for a first day of month;
  - Sending USSD codes with first symbol '#';
  - 3GPP location format (thanks to Graham Inggs);
  - Lots of other fixes.
- Added desktop_database_post(un) and new dependencies.
- Removed merged patches:
  * modem-manager-gui-0.0.16-fix-gcc-warnings.patch
  * modem-manager-gui-0.0.16-notifications-icon.patch
* Fri Jul 25 2014 seanpwatson@live.com
- Patch to change .desktop exec no needed in Factory
* Sun Sep  8 2013 dap.darkness@gmail.com
- Initial build.
